==> testCalculatorDenominalPackage-0.1.tar.gz: testCalculatorDenominalPackage-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'testCalculatorDenominalPackage',         # How you named your package folder (MyLib)
  packages = ['topkek'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'calculates minimum amount of coins for amount',   # Give a short description about your library
  author = 'Rokas Alechnavicius',                   # Type in your name
  author_email = 'rokasalech@gmail.com',      # Type in your E-Mail
  url = 'https://gitlab.com/rokasalech/topkek',   # Provide either the link to your github or to your website
  download_url = 'https://gitlab.com/rokasalech/topkek/-/archive/Release1/topkek-Release1.tar.gz',    # I explain this later on
  keywords = ['test'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  entry_points={
    "console_scripts": [
        "testpackage=topkek.progrem:main",
        ]
    },
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> testCalculatorDenominalPackage-0.2.tar.gz: testCalculatorDenominalPackage-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'testCalculatorDenominalPackage',         # How you named your package folder (MyLib)
  packages = ['test_CalculatorDenominalPackage'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'calculates minimum amount of coins for amount',   # Give a short description about your library
  author = 'Rokas Alechnavicius',                   # Type in your name
  author_email = 'rokasalech@gmail.com',      # Type in your E-Mail
  url = 'https://gitlab.com/rokasalech/topkek',   # Provide either the link to your github or to your website
  download_url = 'https://gitlab.com/rokasalech/topkek/-/archive/Release1/topkek-Release1.tar.gz',    # I explain this later on
  keywords = ['test'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  entry_points={
    "console_scripts": [
        "testCalculatorDenominalPackage=test_CalculatorDenominalPackage.progrem:main",
        ]
    },
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
